django-markymark
================

.. image:: https://badge.fury.io/py/django-markymark.png
    :target: http://badge.fury.io/py/django-markymark
    :alt: Latest PyPI version

.. image:: https://travis-ci.org/moccu/django-markymark.png
   :target: https://travis-ci.org/moccu/django-markymark
   :alt: Latest Travis CI build status

.. image:: https://coveralls.io/repos/moccu/django-markymark/badge.svg
  :target: https://coveralls.io/github/moccu/django-markymark
  :alt: Coverage of master build

.. image:: https://readthedocs.org/projects/django-markymark/badge/?version=latest
    :target: https://readthedocs.org/projects/django-markymark/?badge=latest
    :alt: Latest read the docs build

*django-markymark* provides helpers and tools to integrate markdown into your editor.

.. figure:: https://django-markymark.readthedocs.org/en/latest/_static/logo.gif


Features
========

 * Django form fields to integrate the bootstrap markdown editor (without the dependency on bootstrap)
 * `django-filer <https://github.com/stefanfoulis/django-filer>`_ integration
 * `django-anylink <https://github.com/moccu/django-anylink>`_ integration
 * Various extensions to provide `GitHub Flavored Markdown <https://help.github.com/articles/github-flavored-markdown/>`_


Resources
=========

* `Documentation <https://django-markymark.readthedocs.org/>`_
* `Bug Tracker <https://github.com/moccu/django-markymark/issues>`_
* `Code <https://github.com/moccu/django-markymark/>`_
